:github_url:

.. _wineenv:

.. index::
	single: API
	single: classes
	single: functions
	single: methods

API
===

``wenv`` can not only be used from the command line. It also offers an API and is therefore fully programmable.

.. toctree::
   :maxdepth: 2
   :caption: The API in detail

   env
   envconfig
   pythonversion
